=====
Usage
=====

In case you have general questions about usage, please contact tests@aistat.com

To install the Python package::

    $ pip install meliora


To use Credit Risk Validation Tests in a project::

    import meliora

